@@ -1,5 +1,5 @@
 package ZMQ::FFI;
-$ZMQ::FFI::VERSION = '1.03';
+$ZMQ::FFI::VERSION = '1.04';
 # ABSTRACT: version agnostic Perl bindings for zeromq using ffi
 
 use strict;
@@ -46,7 +46,7 @@ ZMQ::FFI - version agnostic Perl bindings for zeromq using ffi
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -281,7 +281,7 @@ set a context option value
 
     my $socket = $ctx->socket(ZMQ_REQ)
 
-returns a socket of the specified type. See L<SOCKET API> below
+returns a socket of the specified type. See L</SOCKET API> below
 
 =head2 proxy
 
@@ -306,15 +306,7 @@ sets up and runs a C<zmq_device> with specified frontend and backend sockets
 destroy the underlying zmq context. In general you shouldn't have to call this
 directly as it is called automatically for you when the object gets reaped
 
-    {
-        my $ctx = ZMQ::FFI->new();
-        ...
-        # destroy implicitly called in destructor at end of scope
-    }
-
-    $ctx->destroy(); # explicitly destroy the context
-
-    undef $ctx;      # ditto
+See L</CLEANUP> below
 
 =head1 SOCKET API
 
@@ -367,7 +359,9 @@ does socket unbind on the specified endpoint
 
     $socket->set_linger($millis);
 
-get or set the current socket linger period
+get or set the socket linger period. Default: 0 (no linger)
+
+See L</CLEANUP> below
 
 =head2 get_identity, set_identity
 
@@ -455,15 +449,7 @@ true/false depending on the state
 close the underlying zmq socket. In general you shouldn't have to call this
 directly as it is called automatically for you when the object gets reaped
 
-    {
-        my $socket = $ctx->socket($type);
-        ...
-        # close called implicitly in destructor at end of scope
-    }
-
-    $socket->close(); # explicitly close socket
-
-    undef $socket;    # ditto
+See L</CLEANUP> below
 
 =head2 die_on_error
 
@@ -472,7 +458,7 @@ directly as it is called automatically for you when the object gets reaped
     $socket->die_on_error(1);
 
 controls whether error handling should be exceptional or not. This is set to
-true by default. See L<ERROR HANDLING> below
+true by default. See L</ERROR HANDLING> below
 
 =head2 has_error
 
@@ -486,12 +472,63 @@ was no error
 
 =head2 last_strerror
 
-returns the system error string associated with the current socket C<errno>
+returns the human readable system error message associated with the socket
+C<last_errno>
+
+=head1 CLEANUP
+
+With respect to cleanup C<ZMQ::FFI> follows either the L<zeromq guide|http://zguide.zeromq.org/page:all#Making-a-Clean-Exit>
+recommendations or the behavior of other zmq bindings.
+That is:
+
+=over 4
+
+=item * it uses 0 linger by default (this is the default used by L<czmq|https://github.com/zeromq/czmq> and L<jzmq|https://github.com/zeromq/jzmq>)
+
+=item * during object destruction it will call close/destroy for you
+
+=item * it arranges the reference hierarchy such that sockets will be properly
+      cleaned up before their associated contexts
+
+=item * it detects fork/thread situations and ensures sockets/contexts are only
+      cleaned up in their originating process/thread
+
+=item * it guards against double closes/destroys
+
+=back
+
+Given the above you're probably better off letting C<ZMQ::FFI> handle cleanup
+for you. But if for some reason you want to do explicit cleanup yourself you
+can. All the below will accomplish the same thing:
+
+    # implicit cleanup
+    {
+        my $context = ZMQ::FFI->new();
+        my $socket  = $ctx->socket($type);
+        ...
+        # close/destroy called in destructors at end of scope
+    }
+
+    # explicit cleanup
+    $socket->close();
+    $context->destroy();
+
+    # ditto
+    undef $socket;
+    undef $context;
+
+Regarding C<linger>, you can always set this to a value you prefer if
+you don't like the default. Once set the new value will be used when the
+socket is subsequently closed (either implicitly or explicitly):
+
+    $socket->set_linger(-1); # infinite linger
+                             # $context->destroy will block forever
+                             # (or until all pending messages have been sent)
 
 =head1 ERROR HANDLING
 
 By default, ZMQ::FFI checks the return codes of underlying zmq functions for
-you, and in the case of an error it will die with the plain english system
+you, and in the case of an error it will die with the human readable system
 error message.
 
     $ctx->socket(-1);
@@ -517,7 +554,7 @@ errors by checking C<last_errno>:
     while (1) {
         my $msg = $s->recv(ZMQ_DONTWAIT);
 
-        if ($s->last_errno && $s->last_errno == EAGAIN) {
+        if ($s->last_errno == EAGAIN) {
             sleep 1;
         }
         elsif ($s->last_errno) {
@@ -558,6 +595,13 @@ convenience, flexibility, and portability of ffi.
 You can find the detailed performance results that informed this section at:
 L<https://gist.github.com/calid/17df5bcfb81c83786d6f>
 
+=head1 BUGS
+
+C<ZMQ::FFI> is free as in beer in addition to being free as in speech. While
+I've done my best to ensure it's tasty, high quality beer, it probably isn't perfect.
+If you encounter problems, or otherwise see room for improvement, please open
+an issue (or even better a pull request!) on L<github|https://github.com/calid/zmq-ffi>
+
 =head1 SEE ALSO
 
 =over 4
