@@ -1,5 +1,5 @@
 package ZMQ::FFI::ContextRole;
-$ZMQ::FFI::ContextRole::VERSION = '1.03';
+$ZMQ::FFI::ContextRole::VERSION = '1.04';
 use Moo::Role;
 
 # real underlying zmq ctx pointer
@@ -11,7 +11,7 @@ has _ctx => (
 # used to make sure we handle fork situations correctly
 has _pid => (
     is      => 'ro',
-    default => $$,
+    default => sub { $$ },
 );
 
 has soname => (
@@ -52,7 +52,7 @@ ZMQ::FFI::ContextRole
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
