@@ -1,5 +1,5 @@
 package ZMQ::FFI::ErrorHelper;
-$ZMQ::FFI::ErrorHelper::VERSION = '1.03';
+$ZMQ::FFI::ErrorHelper::VERSION = '1.04';
 use Carp;
 use FFI::Platypus;
 use ZMQ::FFI::Util qw(zmq_version);
@@ -49,8 +49,9 @@ sub check_error {
     if ( $rc == -1 ) {
         $self->{last_errno} = $errno;
 
-        $self->fatal($func)
-            if $self->die_on_error;
+        if ($self->die_on_error) {
+            $self->fatal($func)
+        }
     }
 }
 
@@ -69,8 +70,9 @@ sub check_null {
     unless ($obj) {
         $self->{last_errno} = $errno;
 
-        $self->fatal($func)
-            if $self->die_on_error;
+        if ($self->die_on_error) {
+            $self->fatal($func)
+        }
     }
 }
 
@@ -108,7 +110,7 @@ ZMQ::FFI::ErrorHelper
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
