@@ -1,5 +1,5 @@
 package ZMQ::FFI::Util;
-$ZMQ::FFI::Util::VERSION = '1.03';
+$ZMQ::FFI::Util::VERSION = '1.04';
 # ABSTRACT: zmq convenience functions
 
 use strict;
@@ -44,7 +44,9 @@ sub zmq_soname {
             undef $soname;
         }
 
-        last FIND_SONAME if $soname;
+        if ($soname) {
+            last FIND_SONAME;
+        }
     }
 
     if ( !$soname && $die ) {
@@ -109,7 +111,7 @@ ZMQ::FFI::Util - zmq convenience functions
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
